@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 pysteps.cascade.bandpass_filters
 ================================
@@ -52,7 +51,8 @@ import numpy as np
 
 
 def filter_uniform(shape, n):
-    """A dummy filter with one frequency band covering the whole domain. The
+    """
+    A dummy filter with one frequency band covering the whole domain. The
     weights are set to one.
 
     Parameters
@@ -63,10 +63,14 @@ def filter_uniform(shape, n):
     n: int
         Not used. Needed for compatibility with the filter interface.
 
+    Returns
+    -------
+    out: dict
+        A dictionary containing the filter.
     """
     del n  # Unused
 
-    result = {}
+    out = {}
 
     try:
         height, width = shape
@@ -75,19 +79,26 @@ def filter_uniform(shape, n):
 
     r_max = int(max(width, height) / 2) + 1
 
-    result["weights_1d"] = np.ones((1, r_max))
-    result["weights_2d"] = np.ones((1, height, int(width / 2) + 1))
-    result["central_freqs"] = None
-    result["central_wavenumbers"] = None
-    result["shape"] = shape
+    out["weights_1d"] = np.ones((1, r_max))
+    out["weights_2d"] = np.ones((1, height, int(width / 2) + 1))
+    out["central_freqs"] = None
+    out["central_wavenumbers"] = None
+    out["shape"] = shape
 
-    return result
+    return out
 
 
 def filter_gaussian(
-    shape, n, l_0=3, gauss_scale=0.5, gauss_scale_0=0.5, d=1.0, normalize=True
+    shape,
+    n,
+    gauss_scale=0.5,
+    d=1.0,
+    normalize=True,
+    return_weight_funcs=False,
+    include_mean=True,
 ):
-    """Implements a set of Gaussian bandpass filters in logarithmic frequency
+    """
+    Implements a set of Gaussian bandpass filters in logarithmic frequency
     scale.
 
     Parameters
@@ -97,20 +108,20 @@ def filter_gaussian(
         the domain is assumed to have square shape.
     n: int
         The number of frequency bands to use. Must be greater than 2.
-    l_0: int
-        Central frequency of the second band (the first band is always centered
-        at zero).
     gauss_scale: float
-        Optional scaling prameter. Proportional to the standard deviation of
+        Optional scaling parameter. Proportional to the standard deviation of
         the Gaussian weight functions.
-    gauss_scale_0: float
-        Optional scaling parameter for the Gaussian function corresponding to
-        the first frequency band.
     d: scalar, optional
         Sample spacing (inverse of the sampling rate). Defaults to 1.
     normalize: bool
         If True, normalize the weights so that for any given wavenumber
         they sum to one.
+    return_weight_funcs: bool
+        If True, add callable weight functions to the output dictionary with
+        the key 'weight_funcs'.
+    include_mean: bool
+        If True, include the first Fourier wavenumber (corresponding to the
+        field mean) to the first filter.
 
     Returns
     -------
@@ -131,6 +142,8 @@ def filter_gaussian(
     except TypeError:
         height, width = (shape, shape)
 
+    max_length = max(width, height)
+
     rx = np.s_[: int(width / 2) + 1]
 
     if (height % 2) == 1:
@@ -143,13 +156,13 @@ def filter_gaussian(
 
     r_2d = np.roll(np.sqrt(x_grid * x_grid + y_grid * y_grid), dy, axis=0)
 
-    max_length = max(width, height)
-
     r_max = int(max_length / 2) + 1
     r_1d = np.arange(r_max)
 
     wfs, central_wavenumbers = _gaussweights_1d(
-        max_length, n, l_0=l_0, gauss_scale=gauss_scale, gauss_scale_0=gauss_scale_0
+        max_length,
+        n,
+        gauss_scale=gauss_scale,
     )
 
     weights_1d = np.empty((n, r_max))
@@ -166,36 +179,48 @@ def filter_gaussian(
             weights_1d[k, :] /= weights_1d_sum
             weights_2d[k, :, :] /= weights_2d_sum
 
-    result = {"weights_1d": weights_1d, "weights_2d": weights_2d}
-    result["shape"] = shape
+    for i in range(len(wfs)):
+        if i == 0 and include_mean:
+            weights_1d[i, 0] = 1.0
+            weights_2d[i, 0, 0] = 1.0
+        else:
+            weights_1d[i, 0] = 0.0
+            weights_2d[i, 0, 0] = 0.0
+
+    out = {"weights_1d": weights_1d, "weights_2d": weights_2d}
+    out["shape"] = shape
 
     central_wavenumbers = np.array(central_wavenumbers)
-    result["central_wavenumbers"] = central_wavenumbers
+    out["central_wavenumbers"] = central_wavenumbers
 
     # Compute frequencies
     central_freqs = 1.0 * central_wavenumbers / max_length
     central_freqs[0] = 1.0 / max_length
     central_freqs[-1] = 0.5  # Nyquist freq
     central_freqs = 1.0 * d * central_freqs
-    result["central_freqs"] = central_freqs
+    out["central_freqs"] = central_freqs
 
-    return result
+    if return_weight_funcs:
+        out["weight_funcs"] = wfs
+
+    return out
 
 
-def _gaussweights_1d(l, n, l_0=3, gauss_scale=0.5, gauss_scale_0=0.5):
-    e = pow(0.5 * l / l_0, 1.0 / (n - 2))
-    r = [(l_0 * pow(e, k - 1), l_0 * pow(e, k)) for k in range(1, n - 1)]
+def _gaussweights_1d(l, n, gauss_scale=0.5):
+    q = pow(0.5 * l, 1.0 / n)
+    r = [(pow(q, k - 1), pow(q, k)) for k in range(1, n + 1)]
+    r = [0.5 * (r_[0] + r_[1]) for r_ in r]
 
     def log_e(x):
         if len(np.shape(x)) > 0:
             res = np.empty(x.shape)
             res[x == 0] = 0.0
-            res[x > 0] = np.log(x[x > 0]) / np.log(e)
+            res[x > 0] = np.log(x[x > 0]) / np.log(q)
         else:
             if x == 0.0:
                 res = 0.0
             else:
-                res = np.log(x) / np.log(e)
+                res = np.log(x) / np.log(q)
 
         return res
 
@@ -206,28 +231,14 @@ def _gaussweights_1d(l, n, l_0=3, gauss_scale=0.5, gauss_scale_0=0.5):
 
         def __call__(self, x):
             x = log_e(x) - self.c
-            return np.exp(-(x ** 2.0) / (2.0 * self.s ** 2.0))
+            return np.exp(-(x**2.0) / (2.0 * self.s**2.0))
 
     weight_funcs = []
-    central_wavenumbers = [0.0]
-
-    weight_funcs.append(GaussFunc(0.0, gauss_scale_0))
+    central_wavenumbers = []
 
     for i, ri in enumerate(r):
-        rc = log_e(ri[0])
+        rc = log_e(ri)
         weight_funcs.append(GaussFunc(rc, gauss_scale))
-        central_wavenumbers.append(ri[0])
-
-    gf = GaussFunc(log_e(l / 2), gauss_scale)
-
-    def g(x):
-        res = np.ones(x.shape)
-        mask = x <= l / 2
-        res[mask] = gf(x[mask])
-
-        return res
-
-    weight_funcs.append(g)
-    central_wavenumbers.append(l / 2)
+        central_wavenumbers.append(ri)
 
     return weight_funcs, central_wavenumbers
