@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 pysteps.extrapolation.semilagrangian
 ====================================
@@ -132,6 +131,7 @@ def extrapolate(
     n_iter = kwargs.get("n_iter", 1)
     return_displacement = kwargs.get("return_displacement", False)
     interp_order = kwargs.get("interp_order", 1)
+    map_coordinates_mode = kwargs.get("map_coordinates_mode", "constant")
 
     if precip is None and not return_displacement:
         raise ValueError("precip is None but return_displacement is False")
@@ -151,6 +151,8 @@ def extrapolate(
             precip = precip.copy()
             precip[~mask_finite] = 0.0
             mask_finite = mask_finite.astype(float)
+        else:
+            mask_finite = np.ones(precip.shape)
 
     prefilter = True if interp_order > 1 else False
 
@@ -223,7 +225,7 @@ def extrapolate(
             precip_warped = ip.map_coordinates(
                 precip,
                 coords_warped,
-                mode="constant",
+                mode=map_coordinates_mode,
                 cval=outval,
                 order=interp_order,
                 prefilter=prefilter,
@@ -233,23 +235,22 @@ def extrapolate(
                 mask_warped = ip.map_coordinates(
                     mask_min,
                     coords_warped,
-                    mode="constant",
+                    mode=map_coordinates_mode,
                     cval=0,
                     order=1,
                     prefilter=False,
                 )
                 precip_warped[mask_warped < 0.5] = minval
 
-                if allow_nonfinite_values:
-                    mask_warped = ip.map_coordinates(
-                        mask_finite,
-                        coords_warped,
-                        mode="constant",
-                        cval=0,
-                        order=1,
-                        prefilter=False,
-                    )
-                    precip_warped[mask_warped < 0.5] = np.nan
+                mask_warped = ip.map_coordinates(
+                    mask_finite,
+                    coords_warped,
+                    mode=map_coordinates_mode,
+                    cval=0,
+                    order=1,
+                    prefilter=False,
+                )
+                precip_warped[mask_warped < 0.5] = np.nan
 
             precip_extrap.append(np.reshape(precip_warped, precip.shape))
 
