@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
-"""Methods for generating stochastic perturbations of 2d precipitation and
-velocity fields."""
+"""
+Methods for generating stochastic perturbations of 2d precipitation and
+velocity fields.
+"""
 
 from .interface import get_method
 from . import utils, motion, fftgenerators
