@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 from datetime import timedelta
 
@@ -9,6 +7,7 @@ import pytest
 from pysteps import io, motion, nowcasts, verification
 from pysteps.tests.helpers import get_precipitation_fields
 
+
 steps_arg_names = (
     "n_ens_members",
     "n_cascade_levels",
@@ -23,9 +22,9 @@ steps_arg_names = (
 steps_arg_values = [
     (5, 6, 2, None, None, "spatial", 3, 1.30),
     (5, 6, 2, None, None, "spatial", [3], 1.30),
-    (5, 6, 2, "incremental", None, "spatial", 3, 7.25),
-    (5, 6, 2, "sprog", None, "spatial", 3, 8.35),
-    (5, 6, 2, "obs", None, "spatial", 3, 8.30),
+    (5, 6, 2, "incremental", None, "spatial", 3, 7.31),
+    (5, 6, 2, "sprog", None, "spatial", 3, 8.4),
+    (5, 6, 2, "obs", None, "spatial", 3, 8.37),
     (5, 6, 2, None, "cdf", "spatial", 3, 0.60),
     (5, 6, 2, None, "mean", "spatial", 3, 1.35),
     (5, 6, 2, "incremental", "cdf", "spectral", 3, 0.60),
@@ -69,7 +68,7 @@ def test_steps_skill(
         precip_input,
         retrieved_motion,
         timesteps=timesteps,
-        R_thr=metadata["threshold"],
+        precip_thr=metadata["threshold"],
         kmperpixel=2.0,
         timestep=metadata["accutime"],
         seed=42,
@@ -93,6 +92,9 @@ def test_steps_skill(
 
 def test_steps_callback(tmp_path):
     """Test STEPS callback functionality to export the output as a netcdf."""
+
+    pytest.importorskip("netCDF4")
+
     n_ens_members = 2
     n_timesteps = 3
 
@@ -129,7 +131,7 @@ def test_steps_callback(tmp_path):
         precip_input,
         motion_field,
         timesteps=n_timesteps,
-        R_thr=metadata["threshold"],
+        precip_thr=metadata["threshold"],
         kmperpixel=2.0,
         timestep=timestep,
         seed=42,
